@@ -42,12 +42,29 @@ class ApplicationInfo(AbstractModel):
         :param _MinSystemDiskSize: 系统盘大小下限
 注意：此字段可能返回 null，表示取不到有效值。
         :type MinSystemDiskSize: int
+        :param _ApplicationType: 应用类型，目前该项取值可以为PRIVATE_APPLICATION或者PUBLIC_APPLICATION
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ApplicationType: str
+        :param _ApplicationState: 应用状态：CREATING-创建中；ONLINE -正常在线；DELETING -删除中；ARREARS - 欠费隔离
+示例值：ONLINE
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ApplicationState: str
+        :param _CreateTime: 应用创建时间
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CreateTime: str
+        :param _ApplicationSize: 应用大小
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ApplicationSize: int
         """
         self._ApplicationId = None
         self._ApplicationName = None
         self._Description = None
         self._ConfigEnvironment = None
         self._MinSystemDiskSize = None
+        self._ApplicationType = None
+        self._ApplicationState = None
+        self._CreateTime = None
+        self._ApplicationSize = None
 
     @property
     def ApplicationId(self):
@@ -89,6 +106,38 @@ class ApplicationInfo(AbstractModel):
     def MinSystemDiskSize(self, MinSystemDiskSize):
         self._MinSystemDiskSize = MinSystemDiskSize
 
+    @property
+    def ApplicationType(self):
+        return self._ApplicationType
+
+    @ApplicationType.setter
+    def ApplicationType(self, ApplicationType):
+        self._ApplicationType = ApplicationType
+
+    @property
+    def ApplicationState(self):
+        return self._ApplicationState
+
+    @ApplicationState.setter
+    def ApplicationState(self, ApplicationState):
+        self._ApplicationState = ApplicationState
+
+    @property
+    def CreateTime(self):
+        return self._CreateTime
+
+    @CreateTime.setter
+    def CreateTime(self, CreateTime):
+        self._CreateTime = CreateTime
+
+    @property
+    def ApplicationSize(self):
+        return self._ApplicationSize
+
+    @ApplicationSize.setter
+    def ApplicationSize(self, ApplicationSize):
+        self._ApplicationSize = ApplicationSize
+
 
     def _deserialize(self, params):
         self._ApplicationId = params.get("ApplicationId")
@@ -96,6 +145,10 @@ class ApplicationInfo(AbstractModel):
         self._Description = params.get("Description")
         self._ConfigEnvironment = params.get("ConfigEnvironment")
         self._MinSystemDiskSize = params.get("MinSystemDiskSize")
+        self._ApplicationType = params.get("ApplicationType")
+        self._ApplicationState = params.get("ApplicationState")
+        self._CreateTime = params.get("CreateTime")
+        self._ApplicationSize = params.get("ApplicationSize")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             property_name = name[1:]
@@ -116,9 +169,10 @@ class DescribeApplicationsRequest(AbstractModel):
         :param _ApplicationIds: 应用id列表
         :type ApplicationIds: list of str
         :param _Filters: 过滤器，跟ApplicationIds不能共用，支持的filter主要有：
-application-id，精确匹配
-scene-id，精确匹配
-application-name，模糊匹配
+application-id: 精确匹配;
+scene-id: 精确匹配;
+application-name: 模糊匹配;
+application-type: 精确匹配;
         :type Filters: list of Filter
         :param _Offset: 偏移量，默认为0
         :type Offset: int
@@ -127,11 +181,17 @@ MC：1000
 用户：100
 
         :type Limit: int
+        :param _OrderField: 应用列表排序的依据字段。取值范围："CREATED_TIME"：依据应用的创建时间排序。 "APPLICATION_SIZE"：依据应用的大小排序。默认按应用的创建时间排序。
+        :type OrderField: str
+        :param _Order: 输出应用列表的排列顺序。取值范围："ASC"：升序排列。 "DESC"：降序排列。默认按降序排列。
+        :type Order: str
         """
         self._ApplicationIds = None
         self._Filters = None
         self._Offset = None
         self._Limit = None
+        self._OrderField = None
+        self._Order = None
 
     @property
     def ApplicationIds(self):
@@ -165,6 +225,22 @@ MC：1000
     def Limit(self, Limit):
         self._Limit = Limit
 
+    @property
+    def OrderField(self):
+        return self._OrderField
+
+    @OrderField.setter
+    def OrderField(self, OrderField):
+        self._OrderField = OrderField
+
+    @property
+    def Order(self):
+        return self._Order
+
+    @Order.setter
+    def Order(self, Order):
+        self._Order = Order
+
 
     def _deserialize(self, params):
         self._ApplicationIds = params.get("ApplicationIds")
@@ -176,6 +252,8 @@ MC：1000
                 self._Filters.append(obj)
         self._Offset = params.get("Offset")
         self._Limit = params.get("Limit")
+        self._OrderField = params.get("OrderField")
+        self._Order = params.get("Order")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             property_name = name[1:]
@@ -1762,6 +1840,184 @@ class SceneInfo(AbstractModel):
         
 
 
+class StartInstanceRequest(AbstractModel):
+    """StartInstance请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _InstanceId: 实例ID
+        :type InstanceId: str
+        :param _DryRun: 默认为False，True代表只验证接口连通性
+        :type DryRun: bool
+        """
+        self._InstanceId = None
+        self._DryRun = None
+
+    @property
+    def InstanceId(self):
+        return self._InstanceId
+
+    @InstanceId.setter
+    def InstanceId(self, InstanceId):
+        self._InstanceId = InstanceId
+
+    @property
+    def DryRun(self):
+        return self._DryRun
+
+    @DryRun.setter
+    def DryRun(self, DryRun):
+        self._DryRun = DryRun
+
+
+    def _deserialize(self, params):
+        self._InstanceId = params.get("InstanceId")
+        self._DryRun = params.get("DryRun")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class StartInstanceResponse(AbstractModel):
+    """StartInstance返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _TaskId: task任务id
+        :type TaskId: int
+        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self._TaskId = None
+        self._RequestId = None
+
+    @property
+    def TaskId(self):
+        return self._TaskId
+
+    @TaskId.setter
+    def TaskId(self, TaskId):
+        self._TaskId = TaskId
+
+    @property
+    def RequestId(self):
+        return self._RequestId
+
+    @RequestId.setter
+    def RequestId(self, RequestId):
+        self._RequestId = RequestId
+
+
+    def _deserialize(self, params):
+        self._TaskId = params.get("TaskId")
+        self._RequestId = params.get("RequestId")
+
+
+class StopInstanceRequest(AbstractModel):
+    """StopInstance请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _InstanceId: 实例ID
+        :type InstanceId: str
+        :param _StopMode: hai实例关机的模式，目前仅支持关机不收费：
+STOP_CHARGE -- 关闭hai实例，释放计算资源，停止收取计算资源的费用。
+注意：默认值为STOP_CHARGE
+        :type StopMode: str
+        :param _DryRun: 默认为False，True代表只验证接口连通性
+        :type DryRun: bool
+        """
+        self._InstanceId = None
+        self._StopMode = None
+        self._DryRun = None
+
+    @property
+    def InstanceId(self):
+        return self._InstanceId
+
+    @InstanceId.setter
+    def InstanceId(self, InstanceId):
+        self._InstanceId = InstanceId
+
+    @property
+    def StopMode(self):
+        return self._StopMode
+
+    @StopMode.setter
+    def StopMode(self, StopMode):
+        self._StopMode = StopMode
+
+    @property
+    def DryRun(self):
+        return self._DryRun
+
+    @DryRun.setter
+    def DryRun(self, DryRun):
+        self._DryRun = DryRun
+
+
+    def _deserialize(self, params):
+        self._InstanceId = params.get("InstanceId")
+        self._StopMode = params.get("StopMode")
+        self._DryRun = params.get("DryRun")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class StopInstanceResponse(AbstractModel):
+    """StopInstance返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _TaskId: task任务id
+        :type TaskId: int
+        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self._TaskId = None
+        self._RequestId = None
+
+    @property
+    def TaskId(self):
+        return self._TaskId
+
+    @TaskId.setter
+    def TaskId(self, TaskId):
+        self._TaskId = TaskId
+
+    @property
+    def RequestId(self):
+        return self._RequestId
+
+    @RequestId.setter
+    def RequestId(self, RequestId):
+        self._RequestId = RequestId
+
+
+    def _deserialize(self, params):
+        self._TaskId = params.get("TaskId")
+        self._RequestId = params.get("RequestId")
+
+
 class SystemDisk(AbstractModel):
     """描述了操作系统所在块设备即系统盘的信息
 
@@ -1775,9 +2031,13 @@ class SystemDisk(AbstractModel):
         :param _DiskSize: 系统盘大小，单位：GB。默认值为 80
 注意：此字段可能返回 null，表示取不到有效值。
         :type DiskSize: int
+        :param _DiskName: 系统盘分区盘符
+注意：此字段可能返回 null，表示取不到有效值。
+        :type DiskName: str
         """
         self._DiskType = None
         self._DiskSize = None
+        self._DiskName = None
 
     @property
     def DiskType(self):
@@ -1795,10 +2055,19 @@ class SystemDisk(AbstractModel):
     def DiskSize(self, DiskSize):
         self._DiskSize = DiskSize
 
+    @property
+    def DiskName(self):
+        return self._DiskName
+
+    @DiskName.setter
+    def DiskName(self, DiskName):
+        self._DiskName = DiskName
+
 
     def _deserialize(self, params):
         self._DiskType = params.get("DiskType")
         self._DiskSize = params.get("DiskSize")
+        self._DiskName = params.get("DiskName")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             property_name = name[1:]
